﻿/*******************************************************************************
* Copyright (C) 2015-2016 Intel Corp. All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions are met:
*
*  - Redistributions of source code must retain the above copyright notice,
*    this list of conditions and the following disclaimer.
*
*  - Redistributions in binary form must reproduce the above copyright notice,
*    this list of conditions and the following disclaimer in the documentation
*    and/or other materials provided with the distribution.
*
*  - Neither the name of Intel Corp. nor the names of its
*    contributors may be used to endorse or promote products derived from this
*    software without specific prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
* AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
* ARE DISCLAIMED. IN NO EVENT SHALL Intel Corp. OR THE CONTRIBUTORS
* BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
* CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
* SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
* INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
* CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
* ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
* POSSIBILITY OF SUCH DAMAGE.
*******************************************************************************/

using System.Collections.Generic;

namespace FwUpdateAPI
{
    /// <summary>
    /// This class is in use by SdkTbtDevice to get information about sections in FW for hosts,
    /// both for a "live" FW (in a controller) and for files
    /// </summary>
    /// <remarks>For more info, see base class documentation</remarks>
    internal class DeviceFwInfo : FwInfo
    {
        public DeviceFwInfo(FwInfoSource source)
            : base(source)
        {
        }

        public override Dictionary<Sections, SectionDetails> GetSectionInfo()
        {
            var dict = base.GetSectionInfo();

            switch (Source.Info.Generation)
            {
                case HwGeneration.DSL5520_5320:
                case HwGeneration.DSL5110:
                    // There is nothing else that is interesting for us
                    break;

                case HwGeneration.DSL6540_6340:
                case HwGeneration.JHL6240:
                case HwGeneration.JHL6540_6340:
                    GetDROMInfo(dict);
                    break;

                default:
                    throw new TbtException(TbtStatus.SDK_UNKNOWN_CHIP);
            }
            return dict;
        }
    }
}
