/*******************************************************************************
* Copyright (C) 2015 - 2016 Intel Corp. All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions are met:
*
*  - Redistributions of source code must retain the above copyright notice,
*    this list of conditions and the following disclaimer.
*
*  - Redistributions in binary form must reproduce the above copyright notice,
*    this list of conditions and the following disclaimer in the documentation
*    and/or other materials provided with the distribution.
*
*  - Neither the name of Intel Corp. nor the names of its
*    contributors may be used to endorse or promote products derived from this
*    software without specific prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
* AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
* ARE DISCLAIMED. IN NO EVENT SHALL Intel Corp. OR THE CONTRIBUTORS
* BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
* CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
* SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
* INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
* CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
* ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
* POSSIBILITY OF SUCH DAMAGE.
*******************************************************************************/

using System;
using FwUpdateAPI;

namespace FwUpdateCmd
{
    /// <summary>
    /// Base class for command handling. Implements the common commands.
    /// </summary>
    internal abstract class CommandRunner
    {
        /// <summary>
        /// Prints current NVM version
        /// </summary>
        /// <param name="args">The arguments as comes from the command line</param>
        internal void GetCurrentNvmVersion(string[] args)
        {
            Console.WriteLine(GetController(args[1]).GetCurrentFullNvmVersion());
        }

        /// <summary>
        /// Prints current PD version
        /// </summary>
        /// <param name="args">The arguments as comes from the command line</param>
        internal void GetCurrentPdVersion(string[] args)
        {
            var pdVer = GetController(args[1]).GetCurrentPdVersion();
            Console.WriteLine(pdVer);
        }

        /// <summary>
        /// Update FW of selected controller
        /// </summary>
        /// <param name="args">The arguments as comes from the command line</param>
        internal void FwUpdate(string[] args)
        {
            var controller = GetController(args[1]);
            var path = args[2];

            controller.ValidateImage(path);
            SafeModeWarning(controller);

            var currentNvm = Utilities.SafeGetVersion(() => controller.GetCurrentFullNvmVersion());
            var imageNvm = Utilities.GetImageFullNvmVersion(path);
            var currentPd = Utilities.SafeGetVersion(() => controller.GetCurrentPdVersion());
            var imagePd = Utilities.GetImagePdVersion(path);

            var needG3 = (currentPd != imagePd);

            Console.WriteLine("Current NVM version = " + currentNvm);
            Console.WriteLine("Current PD version = " + currentPd);

            Console.WriteLine("File NVM version = " + imageNvm);
            Console.WriteLine("File PD version = " + imagePd);

            Console.WriteLine(Resources.CloseDuringUpdate);
            controller.UpdateFirmwareFromFile(path);
            Console.WriteLine(Resources.FWUpdateSuccessMessage);
            if (needG3)
            {
                Console.WriteLine(controller.GetNeedPowerDownMessage);
            }
        }

        protected abstract SdkTbtBase GetController(string id);

        private static void SafeModeWarning(SdkTbtBase sdkTbtBase)
        {
            var controller = sdkTbtBase as SdkTbtController;
            if (controller != null && controller.IsInSafeMode)
            {
                CmdUtilities.WriteWrappedLine(Resources.MinimalValidationInSafeMode);
            }
        }
    }
}
